@@ -21,11 +21,10 @@ from acme.adders import reverb as adders
 from acme.agents import agent
 from acme.agents.jax import actors
 from acme.agents.jax.dqn import learning
-from acme.jax import networks
 from acme.jax import variable_utils
 import haiku as hk
-from jax.experimental import optix
 import jax.numpy as jnp
+import optax
 import reverb
 import rlax
 
@@ -42,7 +41,7 @@ class DQN(agent.Agent):
   def __init__(
       self,
       environment_spec: specs.EnvironmentSpec,
-      network: networks.QNetwork,
+      network: hk.Transformed,
       batch_size: int = 256,
       prefetch_size: int = 4,
       target_update_period: int = 100,
@@ -52,9 +51,10 @@ class DQN(agent.Agent):
       importance_sampling_exponent: float = 0.2,
       priority_exponent: float = 0.6,
       n_step: int = 5,
-      epsilon: float = 0.,
+      epsilon: float = 0.05,
       learning_rate: float = 1e-3,
       discount: float = 0.99,
+      seed: int = 1,
   ):
     """Initialize the agent."""
 
@@ -65,7 +65,9 @@ class DQN(agent.Agent):
         sampler=reverb.selectors.Prioritized(priority_exponent),
         remover=reverb.selectors.Fifo(),
         max_size=max_replay_size,
-        rate_limiter=reverb.rate_limiters.MinSize(1))
+        rate_limiter=reverb.rate_limiters.MinSize(1),
+        signature=adders.NStepTransitionAdder.signature(
+            environment_spec=environment_spec))
     self._server = reverb.Server([replay_table], port=None)
 
     # The adder is used to insert observations into replay.
@@ -77,7 +79,7 @@ class DQN(agent.Agent):
 
     # The dataset provides an interface to sample from replay.
     dataset = datasets.make_reverb_dataset(
-        client=reverb.TFClient(address),
+        server_address=address,
         environment_spec=environment_spec,
         batch_size=batch_size,
         prefetch_size=prefetch_size,
@@ -85,15 +87,15 @@ class DQN(agent.Agent):
 
     def policy(params: hk.Params, key: jnp.ndarray,
                observation: jnp.ndarray) -> jnp.ndarray:
-      action_values = hk.transform(network).apply(params, observation)
+      action_values = network.apply(params, observation)
       return rlax.epsilon_greedy(epsilon).sample(key, action_values)
 
     # The learner updates the parameters (and initializes them).
     learner = learning.DQNLearner(
         network=network,
         obs_spec=environment_spec.observations,
-        rng=hk.PRNGSequence(1),
-        optimizer=optix.adam(learning_rate),
+        rng=hk.PRNGSequence(seed),
+        optimizer=optax.adam(learning_rate),
         discount=discount,
         importance_sampling_exponent=importance_sampling_exponent,
         target_update_period=target_update_period,
@@ -101,11 +103,11 @@ class DQN(agent.Agent):
         replay_client=reverb.Client(address),
     )
 
-    variable_client = variable_utils.VariableClient(learner, 'foo')
+    variable_client = variable_utils.VariableClient(learner, '')
 
     actor = actors.FeedForwardActor(
         policy=policy,
-        rng=hk.PRNGSequence(1),
+        rng=hk.PRNGSequence(seed),
         variable_client=variable_client,
         adder=adder)
 
