@@ -19,7 +19,6 @@ from typing import Iterator, List, NamedTuple, Tuple
 
 import acme
 from acme.adders import reverb as adders
-from acme.jax import networks
 from acme.jax import utils
 from acme.utils import async_utils
 from acme.utils import counting
@@ -27,8 +26,8 @@ from acme.utils import loggers
 from dm_env import specs
 import haiku as hk
 import jax
-from jax.experimental import optix
 import jax.numpy as jnp
+import optax
 import reverb
 import rlax
 
@@ -37,8 +36,8 @@ class TrainingState(NamedTuple):
   """Holds the agent's training state."""
   params: hk.Params
   target_params: hk.Params
-  opt_state: optix.OptState
-  step: int
+  opt_state: optax.OptState
+  steps: int
 
 
 class LearnerOutputs(NamedTuple):
@@ -53,13 +52,13 @@ class DQNLearner(acme.Learner, acme.Saveable):
   _state: TrainingState
 
   def __init__(self,
-               network: networks.QNetwork,
+               network: hk.Transformed,
                obs_spec: specs.Array,
                discount: float,
                importance_sampling_exponent: float,
                target_update_period: int,
                iterator: Iterator[reverb.ReplaySample],
-               optimizer: optix.InitUpdate,
+               optimizer: optax.GradientTransformation,
                rng: hk.PRNGSequence,
                max_abs_reward: float = 1.,
                huber_loss_parameter: float = 1.,
@@ -68,9 +67,6 @@ class DQNLearner(acme.Learner, acme.Saveable):
                logger: loggers.Logger = None):
     """Initializes the learner."""
 
-    # Transform network into a pure function.
-    network = hk.transform(network)
-
     def loss(params: hk.Params, target_params: hk.Params,
              sample: reverb.ReplaySample):
       o_tm1, a_tm1, r_t, d_t, o_t = sample.data
@@ -109,13 +105,19 @@ class DQNLearner(acme.Learner, acme.Saveable):
       gradients, (keys, priorities) = grad_fn(state.params, state.target_params,
                                               samples)
       updates, new_opt_state = optimizer.update(gradients, state.opt_state)
-      new_params = optix.apply_updates(state.params, updates)
+      new_params = optax.apply_updates(state.params, updates)
+
+      steps = state.steps + 1
+
+      # Periodically update target networks.
+      target_params = rlax.periodic_update(
+          new_params, state.target_params, steps, self._target_update_period)
 
       new_state = TrainingState(
           params=new_params,
-          target_params=state.target_params,
+          target_params=target_params,
           opt_state=new_opt_state,
-          step=state.step + 1)
+          steps=steps)
 
       outputs = LearnerOutputs(keys=keys, priorities=priorities)
 
@@ -148,7 +150,7 @@ class DQNLearner(acme.Learner, acme.Saveable):
         params=initial_params,
         target_params=initial_target_params,
         opt_state=initial_opt_state,
-        step=0)
+        steps=0)
 
     self._forward = jax.jit(network.apply)
     self._sgd_step = jax.jit(sgd_step)
@@ -163,10 +165,6 @@ class DQNLearner(acme.Learner, acme.Saveable):
     # Update our counts and record it.
     result = self._counter.increment(steps=1)
 
-    # Periodically update target network parameters.
-    if self._state.step % self._target_update_period == 0:
-      self._state = self._state._replace(target_params=self._state.params)
-
     # Update priorities in replay.
     if self._replay_client:
       self._async_priority_updater.put(outputs)
