@@ -18,7 +18,6 @@
 from typing import Callable
 
 import acme
-from acme import datasets
 from acme import specs
 from acme.adders import reverb as adders
 from acme.agents.jax.impala import acting
@@ -31,8 +30,8 @@ from acme.utils import loggers
 import dm_env
 import haiku as hk
 import jax
-from jax.experimental import optix
 import numpy as np
+import optax
 import reverb
 
 
@@ -62,8 +61,19 @@ class IMPALA(acme.Actor):
 
     num_actions = environment_spec.actions.num_values
     self._logger = logger or loggers.TerminalLogger('agent')
+
+    extra_spec = {
+        'core_state':
+            hk.without_apply_rng(
+                hk.transform(initial_state_fn, apply_rng=True)).apply(None),
+        'logits':
+            np.ones(shape=(num_actions,), dtype=np.float32)
+    }
+    signature = adders.SequenceAdder.signature(environment_spec, extra_spec)
     queue = reverb.Table.queue(
-        name=adders.DEFAULT_PRIORITY_TABLE, max_size=max_queue_size)
+        name=adders.DEFAULT_PRIORITY_TABLE,
+        max_size=max_queue_size,
+        signature=signature)
     self._server = reverb.Server([queue], port=None)
     self._can_sample = lambda: queue.can_sample(batch_size)
     address = f'localhost:{self._server.port}'
@@ -76,23 +86,19 @@ class IMPALA(acme.Actor):
     )
 
     # The dataset object to learn from.
-    extra_spec = {
-        'core_state': hk.transform(initial_state_fn).apply(None),
-        'logits': np.ones(shape=(num_actions,), dtype=np.float32)
-    }
-    # Remove batch dimensions.
-    dataset = datasets.make_reverb_dataset(
-        client=reverb.TFClient(address),
-        environment_spec=environment_spec,
-        batch_size=batch_size,
-        extra_spec=extra_spec,
-        sequence_length=sequence_length)
+    # We don't use datasets.make_reverb_dataset() here to avoid interleaving
+    # and prefetching, that doesn't work well with can_sample() check on update.
+    dataset = reverb.ReplayDataset.from_table_signature(
+        server_address=address,
+        table=adders.DEFAULT_PRIORITY_TABLE,
+        max_in_flight_samples_per_worker=1,
+        sequence_length=sequence_length,
+        emit_timesteps=False)
+    dataset = dataset.batch(batch_size, drop_remainder=True)
 
-    rng = hk.PRNGSequence(seed)
-
-    optimizer = optix.chain(
-        optix.clip_by_global_norm(max_gradient_norm),
-        optix.adam(learning_rate),
+    optimizer = optax.chain(
+        optax.clip_by_global_norm(max_gradient_norm),
+        optax.adam(learning_rate),
     )
 
     self._learner = learning.IMPALALearner(
@@ -100,7 +106,7 @@ class IMPALA(acme.Actor):
         unroll_fn=unroll_fn,
         initial_state_fn=initial_state_fn,
         iterator=dataset.as_numpy_iterator(),
-        rng=rng,
+        rng=hk.PRNGSequence(seed),
         counter=counter,
         logger=logger,
         optimizer=optimizer,
@@ -112,9 +118,12 @@ class IMPALA(acme.Actor):
 
     variable_client = variable_utils.VariableClient(self._learner, key='policy')
     self._actor = acting.IMPALAActor(
-        forward_fn=jax.jit(hk.transform(forward_fn).apply, backend='cpu'),
+        forward_fn=jax.jit(
+            hk.without_apply_rng(hk.transform(forward_fn,
+                                              apply_rng=True)).apply,
+            backend='cpu'),
         initial_state_fn=initial_state_fn,
-        rng=rng,
+        rng=hk.PRNGSequence(seed),
         adder=adder,
         variable_client=variable_client,
     )
@@ -129,10 +138,15 @@ class IMPALA(acme.Actor):
   ):
     self._actor.observe(action, next_timestep)
 
-  def update(self):
+  def update(self, wait: bool = False):
+    should_update_actor = False
     # Run a number of learner steps (usually gradient steps).
     while self._can_sample():
       self._learner.step()
+      should_update_actor = True
+    if should_update_actor:
+      # Update actor weights after learner.
+      self._actor.update(wait)
 
   def select_action(self, observation: np.ndarray) -> int:
     return self._actor.select_action(observation)
