@@ -25,9 +25,9 @@ from acme.utils import counting
 from acme.utils import loggers
 import haiku as hk
 import jax
-from jax.experimental import optix
 import jax.numpy as jnp
 import numpy as np
+import optax
 import reverb
 import rlax
 import tree
@@ -36,7 +36,7 @@ import tree
 class TrainingState(NamedTuple):
   """Training state consists of network parameters and optimiser state."""
   params: hk.Params
-  opt_state: optix.OptState
+  opt_state: optax.OptState
 
 
 class IMPALALearner(acme.Learner, acme.Saveable):
@@ -48,7 +48,7 @@ class IMPALALearner(acme.Learner, acme.Saveable):
       unroll_fn: networks.PolicyValueRNN,
       initial_state_fn: Callable[[], hk.LSTMState],
       iterator: Iterator[reverb.ReplaySample],
-      optimizer: optix.InitUpdate,
+      optimizer: optax.GradientTransformation,
       rng: hk.PRNGSequence,
       discount: float = 0.99,
       entropy_cost: float = 0.,
@@ -59,14 +59,20 @@ class IMPALALearner(acme.Learner, acme.Saveable):
   ):
 
     # Transform into pure functions.
-    unroll_fn = hk.transform(unroll_fn)
-    initial_state_fn = hk.transform(initial_state_fn)
+    unroll_fn = hk.without_apply_rng(hk.transform(unroll_fn, apply_rng=True))
+    initial_state_fn = hk.without_apply_rng(
+        hk.transform(initial_state_fn, apply_rng=True))
 
     def loss(params: hk.Params, sample: reverb.ReplaySample) -> jnp.ndarray:
       """Entropy-regularised actor-critic loss."""
 
       # Extract the data.
-      observations, actions, rewards, discounts, extra = sample.data
+      data = sample.data
+      observations, actions, rewards, discounts, extra = (data.observation,
+                                                          data.action,
+                                                          data.reward,
+                                                          data.discount,
+                                                          data.extras)
       initial_state = tree.map_structure(lambda s: s[0], extra['core_state'])
       behaviour_logits = extra['logits']
 
@@ -119,7 +125,7 @@ class IMPALALearner(acme.Learner, acme.Saveable):
 
       # Apply updates
       updates, new_opt_state = optimizer.update(gradients, state.opt_state)
-      new_params = optix.apply_updates(state.params, updates)
+      new_params = optax.apply_updates(state.params, updates)
 
       metrics = {
           'loss': loss_value,
@@ -148,7 +154,7 @@ class IMPALALearner(acme.Learner, acme.Saveable):
 
     # Set up logging/counting.
     self._counter = counter or counting.Counter()
-    self._logger = logger or loggers.TerminalLogger('learner', time_delta=1.)
+    self._logger = logger or loggers.make_default_logger('learner')
 
   def step(self):
     """Does a step of SGD and logs the results."""
