@@ -15,14 +15,18 @@
 
 """JAX networks implemented with Haiku."""
 
+from acme.jax.networks.atari import AtariTorso
 from acme.jax.networks.atari import DeepIMPALAAtariNetwork
 from acme.jax.networks.atari import dqn_atari_network
+from acme.jax.networks.atari import R2D2AtariNetwork
 from acme.jax.networks.base import Logits
 from acme.jax.networks.base import PolicyValueRNN
 from acme.jax.networks.base import QNetwork
+from acme.jax.networks.base import RecurrentQNetwork
 from acme.jax.networks.base import Value
 from acme.jax.networks.continuous import LayerNormMLP
 from acme.jax.networks.continuous import NearZeroInitializedLinear
+from acme.jax.networks.distributional import CategoricalHead
 from acme.jax.networks.policy_value import PolicyValueHead
 from acme.jax.networks.rescaling import ClipToSpec
 from acme.jax.networks.rescaling import TanhToSpec
