@@ -32,7 +32,8 @@ def dummy_network(x):
 class VariableClientTest(absltest.TestCase):
 
   def test_update(self):
-    init_fn, _ = hk.transform(dummy_network)
+    init_fn, _ = hk.without_apply_rng(
+        hk.transform(dummy_network, apply_rng=True))
     params = init_fn(jax.random.PRNGKey(1), jnp.zeros(shape=(1, 32)))
     variable_source = fakes.VariableSource(params)
     variable_client = variable_utils.VariableClient(
