@@ -15,7 +15,10 @@
 """Various losses for training agent components (policies, critics, etc)."""
 
 from acme.tf.losses.distributional import categorical
+from acme.tf.losses.distributional import multiaxis_categorical
 from acme.tf.losses.dpg import dpg
 from acme.tf.losses.huber import huber
+# from acme.tf.losses.mompo import KLConstraint
+# from acme.tf.losses.mompo import MultiObjectiveMPO
 from acme.tf.losses.mpo import MPO
 from acme.tf.losses.r2d2 import transformed_n_step_loss
