@@ -16,15 +16,18 @@
 """Tests for csv logging."""
 
 import csv
+import gc
+import os
 
 from absl.testing import absltest
 from acme.testing import test_utils
+from acme.utils import paths
 from acme.utils.loggers import csv as csv_logger
 
 
 class CSVLoggingTest(test_utils.TestCase):
 
-  def test_logging(self):
+  def test_logging_input_is_directory(self):
     inputs = [{
         'c': 'foo',
         'a': '1337',
@@ -36,14 +39,47 @@ class CSVLoggingTest(test_utils.TestCase):
     }]
     directory = self.get_tempdir()
     label = 'test'
-    logger = csv_logger.CSVLogger(directory=directory, label=label)
+    logger = csv_logger.CSVLogger(directory_or_file=directory, label=label)
     for inp in inputs:
       logger.write(inp)
-    with open(logger.file_path) as f:
+    outputs = []
+    file_path = logger.file_path
+
+    # Make sure logger flushed all pending writes to disk.
+    del logger
+    gc.collect()
+
+    with open(file_path) as f:
       csv_reader = csv.DictReader(f)
-      for idx, row in enumerate(csv_reader):
-        row = dict(row)
-        self.assertEqual(row, inputs[idx])
+      for row in csv_reader:
+        outputs.append(dict(row))
+    self.assertEqual(outputs, inputs)
+
+  def test_logging_input_is_file(self):
+    inputs = [{
+        'c': 'foo',
+        'a': '1337',
+        'b': '42.0001',
+    }, {
+        'c': 'foo2',
+        'a': '1338',
+        'b': '43.0001',
+    }]
+    directory = paths.process_path(
+        self.get_tempdir(), 'logs', 'my_label', add_uid=True)
+    file = open(os.path.join(directory, 'logs.csv'), 'a')
+    logger = csv_logger.CSVLogger(directory_or_file=file)
+    for inp in inputs:
+      logger.write(inp)
+    outputs = []
+    file_path = logger.file_path
+    file.close()
+
+    with open(file_path) as f:
+      csv_reader = csv.DictReader(f)
+      for row in csv_reader:
+        outputs.append(dict(row))
+    self.assertEqual(outputs, inputs)
 
 
 if __name__ == '__main__':
